# Dataset of cortical activity recorded with high spatial resolution from anesthetized rats

## Summary

Here, we present an electrophysiological dataset recorded from the neocortex of twenty rats anesthetized with ketamine/xylazine. The wideband, spontaneous recordings were acquired with a single-shank silicon-based probe having 128 densely packed recording sites arranged in a 32x4 array. Using spike sorting, the activity of a total of 7126 single units was extracted from all layers of the cortex. Here, we share raw neural recordings, as well as spike times, extracellular spike waveforms and several properties of units packaged in a standardized electrophysiological data format. For technical validation of our dataset, we provide the distributions of derived single unit properties along with various spike sorting quality metrics.

## Downloading the dataset

Recordings can be downloaded individually through the web interface or using the [GIN Client](https://gin.g-node.org/G-Node/Info/wiki/GIN+CLI+Setup#quickstart).

Using the GIN Client, the dataset can be downloaded the following way:

1. A local repository needs to be initialized in the current directory using the following command:
```
gin init
```
2. Then, the remote repository located on GIN needs to be added:
```
gin add-remote RemoteRepo gin:UlbertLab/High_Resolution_Cortical_Spikes
```
3. After that, the user needs to download the contents of the repository:
```
gin dowload
```
4. The previous command will download the small files and the file structure of the repository. Large files will be included as pointer files but the data will not be included. To get the content of the big files you need to download them individually the following way:

```
gin get-content filePath/fileName
```
**Examples**

a.) Downloading a single file:

```
gin get-content allSingleUnits.nwb
gin get-content Rat01/Insertion1/Depth1/Rat01_Insertion1_Depth1.nwb
```
b.) Downloading all files located in a particular directory:
```
gin get-content Rat01
```

c.) Or you may download the contents of all files by using the command with no arguments:

```
gin get-content

```


For more ways of accessing the data, please refer to GIN's [FAQ](https://gin.g-node.org/G-Node/Info/wiki/FAQ+Troubleshooting#how-can-i-access-the-data).


## Repository structure

Each recording and corresponding metadata, single unit properties and quality metrics were packaged in the Neurodata Without Borders: Neurophysiology version 2.0 (NWB:N 2.0) data format using the MatNWB API. A single NWB file was created from each recording. NWB files were placed in folders based on the identifier of the animal (from Rat01 to Rat20), insertion sequence (Insertion1 or Insertion2) and cortical depth (from Depth1 to Depth3). The filename of the NWB file (identifier) was constructed by concatenating the above information (e.g., Rat01_Insertion2_Depth3).

## NWB file structure
The NWB file contains several main groups which are similar to directories. The acquisition group contains the continuous wideband 128-channel data (‘wideband_multichannel_recording’) in a compressed form, as well as several parameters related to the raw data such as the measurement unit or the data conversion number. The general group contains metadata about the experiments and consists of several subgroups, related to the recording probe (‘general/devices’; ‘general/extracellular_ephys’) or the subjects of the experiments (‘general/subject’). Former subgroups carry information about the probe location (brain area and stereotaxic coordinates) and the relative positions and laminar location of recordings sites, while the latter contains metadata about the animal (e.g., sex, species, subject ID, or weight). Information about spike sorting and single units and corresponding data are available in the units group. For each unit, we included here the mean and standard deviation of their spike waveform on all channels, calculated both from the filtered (‘mean_waveform_all_channels_filt’; ’waveform_sd_all_channels_filt’) and the wideband data (‘mean_waveform_all_channels_raw’; ’ waveform_sd_all_channels_raw’). For an easier visualization of the spike waveform in two dimensions, we have also added an array which contains the mean spike waveform in the 32 x 4 shape of the array (‘mean_waveform_all_channels_filt_32x4’; ’mean_waveform_all_channels_raw_32x4’). Furthermore, the spike waveform recorded on the channel with the largest spike (i.e., peak waveform channel) was saved separately (‘mean_waveform_peak_channel_filt’, ‘mean_waveform_peak_channel_raw’). Several single unit properties and cluster quality metrics, as well as the spike times and spike count of each unit were saved in the units group. Furthermore, to aid users in selecting and analyzing a subset of this dataset appropriate for the research goals, we also created an NWB file (‘allSingleUnits.nwb’) which contains all single unit with all the properties listed above, along with the identifier of the recording they originate from (‘units/session_id’).

## Related Publications
* Fiáth, R., Raducanu, B. C., Musa, S., Andrei, A., Lopez, C. M., van Hoof, C., Ruther, P., Aarts, A., Horváth, D., Ulbert, I. (2018) A silicon-based neural probe with densely-packed low-impedance titanium nitride microelectrodes for ultrahigh-resolution in vivo recordings. Biosensors and Bioelectronics 106: 86-92. https://doi.org/10.1016/j.bios.2018.01.060

## Licensing
[![LicenseImg](https://i.creativecommons.org/l/by/4.0/88x31.png)](https://creativecommons.org/licenses/by/4.0/)

The dataset is licensed under a [Creative Commons Attribution 4.0 International License](https://creativecommons.org/licenses/by/4.0/).

See the [LICENSE file](https://gin.g-node.org/UlbertLab/High_Resolution_Cortical_Spikes/src/master/LICENSE) for the full license.


